#*********************************************************************
# R code for drawing map output variables of SEIB-DGVM ver. 3.0       
#                                                                     
# All rights are reserved by Dr. Hisashi SATO                         
# @Graduate School of Environmental Studies, Nagoya University        
#*********************************************************************

#____________________ Common procedure ____________________ 
#Set environment
   #Working directory
   setwd('./result_visualize/') 
   
   #Missing value
   Missing  =  0
   
   #Grid size (length on a side @ deg)
   GridSize   = 0.5
   
   #Pixel size of a grid
   PixSize   = 2.0
   
   #Visualizing area (designated by grid numbers)
   #(GTMIP2)
   LatNoStart = 20
   LatNoEnd   = 100
   LonNoStart = 521
   LonNoEnd   = 720
   
#Compute valiables for coodination and image size
   
   #Row and column numbers of drawing area
   Lat      = LatNoEnd - LatNoStart + 1
   Lon      = LonNoEnd - LonNoStart + 1
   
   #Vertical and horizontal picture size @ pixel
   width_size  = Lon * PixSize
   height_size = Lat * PixSize
   
   #Latitude and longitude at the center of grid of the most south-west grid cell
   Lat1_loc =    90.0 - (LatNoEnd   - 0.5) * 0.5 #(North:+ , Sourth:-)
   Lon1_loc = - 180.0 + (LonNoStart - 0.5) * 0.5 #(West :- , East  :+)
   
   #Latitude coordinate
   y <- array(0.0, dim=c(Lat))                          #Prepare array y
   for(i in 1:Lat)   y[i] <- Lat1_loc + (i-1)*GridSize  #Input latitude from south to north
   
   #Longitude coordinate
   x <- array(0.0, dim=c(Lon))                          #Prepare attay x
   for(i in 1:Lon)   x[i] <- Lon1_loc + (i-1)*GridSize  #Input longitude from west to east
   
#Other preparation
   #Activate map library
   library(maps)
   library(RColorBrewer)
  #library(colorRamps)
   
   #Prepare data aray
   z  <- array(Missing, dim=c(Lon,Lat))

#____________________ Subroutines for color palette ____________________ 
set_color_topo <- function(num_col) {
   col <-  c(num_col)                #Prepare color variable (this must be division number - 1)
   col <- c(topo.colors(num_col))    #Give color from a palette
   col <- col[length(col):1]         #Turn upside down for color palette
   col[1]  = "white"                 #Change minimum class color
   return(col)                       }
   
set_color_topo2 <- function(num_col) {
   col <-  c(num_col)                #Prepare color variable (this must be division number - 1)
   col <- c(topo.colors(num_col))    #Give color from a palette
   col <- col[length(col):1]         #Turn upside down for color palette
   col[1]        = "white"           #Change minimum class color
   col[num_col]  = "gray "           #Change maximum class color
   return(col)                       }
   
set_color_heat <- function(num_col) {
   col <-  c(num_col)                #Prepare color variable (this must be division number - 1)
   col <- c(heat.colors(num_col))    #Give color from a palette
   col <- col[length(col):1]         #Turn upside down for color palette
   col[1]  = "white"                 #Change minimum class color
   return(col)                       }
   
set_color_terrain <- function(num_col) {
   col <-  c(num_col)                #Prepare color variable (this must be division number - 1)
   col <- c(terrain.colors(num_col)) #Give color from a palette
   col <- col[length(col):1]         #Turn upside down for color palette
   col[1]  = "antiquewhite1"         #Change minimum class color
   return(col)                       }

set_color_PlusMinus <- function(num_col) {
   col <-  c(num_col)                  #Prepare color variable (this must be division number - 1)
#  col <- c(matlab.like(num_col))      #Give color from a palette
#  col <- c(cm.colors(num_col))        #Give color from a palette
   col <- brewer.pal(num_col, "PiYG")  #Give color from a palette
   col[6] <- "white"                   #For Zero Color
#  col <- col[length(col):1]           #Turn upside down for color palette
   return(col)                       }


#____________________ Subroutines for data reading and coordination conversion ____________________ 
read_data <- function(fname) {
   d <- read.csv(fname, header=F)
   for (i in 1:Lat) {
   for (j in 1:Lon) {
      #Tuen upside down for latitude, and replace row and column
      z[j,i] <- d[Lat-i+1,j] 
   }
   }
   return(z)
}

#____________________ Subroutine for drawing color pannel ____________________
# LabelName :Label on the top of color pannel
# DivedNum  :Cell number of color pannel
# LabelNum  :Number of value below the color pannel
# IncreStep :Increment of color pannel

# draw_panel <- function(LabelName, DivedNum, LabelNum, IncreStep) {
#    x_start <-  -15
#    x_width <-    5
#    y_start <-  -47
#    y_width <-    5
#    
# draw_panel <- function(LabelName, DivedNum, LabelNum, IncreStep) {
#    x_start <-   60
#    x_width <-    5
#    y_start <-   75
#    y_width <-    5
#    
draw_panel <- function(LabelName, DivedNum, LabelNum, IncreStep) {
   x_start <-   140
   x_width <-    2
   y_start <-   74 #]܂
   y_width <-    3
   
   # gOւ̕`
   par(xpd=T)
   
   #Write label on top of the color pannel
   text(x_start, y_start+2, pos=4, LabelName)
   
   #Draw white belt under color pannel
   x_end <-  x_start+x_width*LabelNum
   polygon( c(x_start, x_end, x_end, x_start), c(y_start, y_start, y_start-y_width, y_start-y_width), col='white') 
   
   #Draw color pannel
   if (DivedNum==0 || LabelNum==0) {return}
   i <- floor(DivedNum/ LabelNum)
   for (j in 1:DivedNum) {
      polygon( c(x_start, x_start+x_width, x_start+x_width, x_start), c(y_start, y_start, y_start-y_width, y_start-y_width), col=col[j])
      if (floor(j/i) == j/i) {text(x_start+0.5*x_width, y_start-y_width*0.7, pos=1, j*IncreStep)}
      x_start <- x_start+x_width
   }
   }



#____________________ Subroutine for drawing a distribution map 1 ____________________
draw_dist <- function(DivedNum,PannelStep,col,x,y,z) {
   PannelMax  <- DivedNum * PannelStep                #J[pl̍őlZo
   br  <- c(seq(from=0, to=PannelMax, by=PannelStep)) #l̕_̐ݒP(̎d؂)
   br[DivedNum+1]  = PannelMax*10                     #l̕_̐ݒQ(V)
   par(mar = c(0,0,0,0) )                           #EEEȄœ}[Wݒ
   frame()                                            #ʂ̃NA
   image(x, y, z, breaks=br, col=col, xlab='', ylab='', axes = FALSE) #}bsO
   map(add=T, interior=FALSE)                                         #n}dˏ
   }
   
#____________________ Subroutine for drawing a distribution map 2 ____________________
draw_dist_LAI <- function(DivedNum,PannelStep,col,x,y,z) {
   PannelMax  <- DivedNum * PannelStep                #J[pl̍őlZo
   br  <- c(seq(from=0, to=PannelMax, by=PannelStep)) #l̕_̐ݒP(̎d؂)
   br[DivedNum+1]  = PannelMax*10                     #l̕_̐ݒQ(V)
   br[1]           = 0.01                             #l̕_̐ݒR(n_)
   par(mar = c(0,0,0,0) )                           #EEEȄœ}[Wݒ
   frame()                                            #ʂ̃NA
   image(x, y, z, breaks=br, col=col, xlab='', ylab='', axes = FALSE) #}bsO
   map(add=T, interior=FALSE)                                         #n}dˏ
   }
   
#____________________ Biome ____________________ 
   DivedNum   <- 12 #J[pl̕
   PannelStep <- 1  #J[pl̑
   
   z <- read_data('out_biome.txt') #f[^ǂ݂ƁA`
   
   #F̐ݒs
   col <- set_color_topo(DivedNum) 
   col[ 0] <- "white"         # 0: - water -
   col[ 1] <- "white"         # 1: Polar desert
   col[ 2] <- "violet"        # 2: Arctic/Alpine-tundra
   col[ 3] <- "red"           # 3: Tropical evergreen forest
   col[ 4] <- "darksalmon"    # 4: Tropical deciduous forest
   col[ 5] <- "orange"        # 5: Temperate conifer forest
   col[ 6] <- "aquamarine"    # 6: Temperate broad-leaved evergreen forest
   col[ 7] <- "aquamarine2"   # 7: Temperate deciduous forest
   col[ 8] <- "aquamarine4"   # 8: Boreal evergreen forest
   col[ 9] <- "steelblue1"    # 9: Boreal deciduous forest
   col[10] <- "steelblue4"    #10: Xeric woodland / scrub
   col[11] <- "bisque"        #11: Grassland / steppe / Savanna
   col[12] <- "bisque3"       #12: Desert
   
   png('out_biome.png', width=width_size, height=height_size) #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)             #}{̂̕`
   
   #}̕` ______
   x_start <-   114
   x_width <-    5
   y_start <-   84 #]܂
   y_width <-    4
   
   # gOւ̕`
   par(xpd=T)
   
   #Write label on top of the color pannel
   text(x_start, y_start+2, pos=4, "Biome Type")
   
   #Draw color pannel
   for (j in 1:DivedNum) {
      polygon( c(x_start, x_start+x_width, x_start+x_width, x_start), c(y_start, y_start, y_start-y_width, y_start-y_width), col=col[j])
      text(x_start+0.5*x_width, y_start-y_width*0.7, pos=1, j)
      x_start <- x_start+x_width
   }
   
   #foCXhCo ______
   dev.off()
   
#____________________ Fire number (n/year) ____________________ 
#   DivedNum   <- 20     #J[pl̕
#   PannelStep <- 0.025  #J[pl̑
   
   DivedNum   <- 20     #J[pl̕
   PannelStep <- 0.0025  #J[pl̑

   z   <- read_data('out_fire.txt')                               #f[^ǂ݂ƁA`
   col <- set_color_topo(DivedNum)                                #F̐ݒs
   
   png('out_fire.png', width=width_size, height=height_size)      #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)                 #}{̂̕`
   draw_panel('Fire Frequency (n/year)', DivedNum, 4, PannelStep) #J[pldˏ
   dev.off()                                                      #foCXhCo
   
#____________________ Biomass ____________________ 
   DivedNum   <- 20   #J[pl̕
   PannelStep <- 0.5 #J[pl̑
   
   z <- read_data('out_wbiomass.txt')                            #f[^ǂ݂ƁA`
   col <- set_color_heat(DivedNum)                               #F̐ݒs
   
   png('out_wbiomass.png', width=width_size, height=height_size) #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)                #}{̂̕`
   draw_panel('Biomass (KgC/m2)', DivedNum, 4, PannelStep)       #J[pldˏ
   dev.off()                                                     #foCXhCo

#____________________ GPP ____________________ 
   DivedNum   <- 12                    #J[pl̕
   PannelStep <- 0.2                   #J[pl̑
   
   z <- read_data('out_gpp.txt')       #f[^ǂ݂ƁA`
   col <- set_color_topo(DivedNum)     #F̐ݒs
   
   png('out_gpp.png', width=width_size, height=height_size)   #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)             #}{̂̕`
   draw_panel('GPP (gC/m2/yr)', DivedNum, 4, PannelStep*1000) #J[pldˏ
   dev.off()                                                  #foCXhCo
   
#____________________ NPP ____________________ 
   DivedNum   <- 12                #J[pl̕
   PannelStep <- 0.1               #J[pl̑
   
   z <- read_data('out_npp.txt')   #f[^ǂ݂ƁA`
   col <- set_color_topo(DivedNum) #F̐ݒs
   
   png('out_npp.png', width=width_size, height=height_size)   #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)             #}{̂̕`
   draw_panel('NPP (gC/m2/yr)', DivedNum, 4, PannelStep*1000) #J[pldˏ
   dev.off()                                                  #foCXhCo
   
#____________________ NEP ____________________ 
   DivedNum   <- 11               #J[pl̕ (ɂȂ悤ɐݒ肷邱)
   PannelStep <- 0.1              #J[pl̑
   
   z <- read_data('out_nep.txt')         #f[^ǂ݂ƁA`
   col <- set_color_PlusMinus(DivedNum)  #F̐ݒs
   
   png('out_nep.png', width=width_size, height=height_size)   #foCXhCoJ
   par(xpd=T)                                                 #gOւ̕`
   
   PannelMin  <- -0.5*(DivedNum-1) * PannelStep - 0.5 * PannelStep #J[pl̍őlZo
   PannelMax  <-  0.5*(DivedNum-1) * PannelStep + 0.5 * PannelStep #J[pl̍őlZo

   br  <- c(seq(from=PannelMin, to=PannelMax, by=PannelStep)) #l̕_̐ݒP(̎d؂)
   br[1]           = -PannelMax*10                            #l̕_̐ݒQ({g)
   br[DivedNum+1]  =  PannelMax*10                            #l̕_̐ݒR(V)
   
   par(mar = c(0,0,3.2,0) )                                           #EEEȄœ}[Wݒ
   frame()                                                            #ʂ̃NA
   image(x, y, z, breaks=br, col=col, xlab='', ylab='', axes = FALSE) #}bsO
   map(add=T, interior=FALSE)                                         #n}dˏ
   
   #J[pldˏ
   x_start <-   100
   y_start <-   86 #]ւ̂͂ݏolĂ
   x_width <-    6
   y_width <-    4
   
   LabelNum <-   5
   IncreStep <-  PannelStep*1000
   
   text(x_start, y_start+2, pos=4, 'NEP (gC/m2/yr)') #Write label on top of the color pannel
   
   #Draw white belt under color pannel
   x_end <-  x_start+x_width*DivedNum
   polygon( c(x_start, x_end, x_end, x_start), c(y_start, y_start, y_start-y_width, y_start-y_width), col='white')
   
   #Draw color pannel
   i <- floor(DivedNum/ LabelNum)
   for (j in 1:DivedNum) {
      polygon( c(x_start, x_start+x_width, x_start+x_width, x_start), c(y_start, y_start, y_start-y_width, y_start-y_width), col=col[j])
      if (floor(j/i) == j/i) {text(x_start+0.5*x_width, y_start-y_width*0.7, pos=1, j*IncreStep-600)}
      x_start <- x_start+x_width
   }
   
   #foCXhCo
   dev.off()                                                  
   
#____________________ HR ____________________ 
   DivedNum   <- 12               #J[pl̕
   PannelStep <- 0.1              #J[pl̑
   
   z <- read_data('out_hr.txt')    #f[^ǂ݂ƁA`
   col <- set_color_topo(DivedNum) #F̐ݒs
   
   png('out_hr.png', width=width_size, height=height_size)    #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)             #}{̂̕`
   draw_panel('HR (gC/m2/yr)', DivedNum, 6, PannelStep*1000)  #J[pldˏ
   dev.off()                                                  #foCXhCo
   
#____________________ Maximum ALD (m) ____________________ 
   DivedNum   <- 20                #J[pl̕
   PannelStep <- 0.1               #J[pl̑
   
   z <- read_data('out_ald_max.txt') #f[^ǂ݂ƁA`
   col <- set_color_topo2(DivedNum)   #F̐ݒs
   
   png('out_ald_max.png', width=width_size, height=height_size)           #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)                         #}{̂̕`
   draw_panel('Maximuum Active Layer Depth (m)', DivedNum, 5, PannelStep) #J[pldˏ
   dev.off()                                                              #foCXhCo
   
#____________________ JJA Available Water within the Soil layers 1 to 5 ____________________ 
   DivedNum   <- 20                 #J[pl̕
   PannelStep <- 0.02               #J[pl̑
   
   z <- read_data('out_water_JJA.txt') #f[^ǂ݂ƁA`
   for (i in 1:Lat) {
   for (j in 1:Lon) {
      z[j,i] <- z[j,i] / 500.0   #mm -> fraction
   }
   }
   col <- set_color_topo(DivedNum)  #F̐ݒs
   
   png('out_water_JJA.png', width=width_size, height=height_size)                      #foCXhCoJ
   draw_dist (DivedNum, PannelStep, col, x, y, z)                                      #}{̂̕`
   draw_panel('JJA available Soil Water @ 0-50cm depth (fraction)', DivedNum, 4, PannelStep) #J[pldˏ
   dev.off()                                                                           #foCXhCo
   
#____________________ LAI ____________________ 
   DivedNum   <- 14                    #J[pl̕
   PannelStep <- 0.25                   #J[pl̑
   
   col <- set_color_terrain(DivedNum)  #_ƐF̐ݒ
   
   #`a1
   z <- read_data('out_lai_amean.txt')                             #f[^ǂ݂ƁA`
   png('out_lai_amean.png', width=width_size, height=height_size)  #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)              #}{̂̕`
   draw_panel('Annual Mean LAI (m2/m2)', DivedNum, 7, PannelStep)  #J[pldˏ
   dev.off()                                                       #foCXhCo
   
   #`a2
   z <- read_data('out_lai_amean_t.txt')                                        #f[^ǂ݂ƁA`
   png('out_lai_amean_t.png', width=width_size, height=height_size)             #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)                           #}{̂̕`
   draw_panel('Annual Mean LAI of Woody PFTs(m2/m2)', DivedNum, 7, PannelStep)  #J[pldˏ
   dev.off()                                                                    #foCXhCo
   
   #`a3
   z <- read_data('out_lai_amean_g.txt')                                        #f[^ǂ݂ƁA`
   png('out_lai_amean_g.png', width=width_size, height=height_size)             #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)                           #}{̂̕`
   draw_panel('Annual Mean LAI of Grass PFT (m2/m2)', DivedNum, 7, PannelStep)  #J[pldˏ
   dev.off()                                                                    #foCXhCo
   
   #`b1
   z <- read_data('out_lai_max.txt')                                 #f[^ǂ݂ƁA`
   png('out_lai_max.png', width=width_size, height=height_size)      #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)                #}{̂̕`
   draw_panel('Annual Maximum LAI (m2/m2)', DivedNum, 7, PannelStep) #J[pldˏ
   dev.off()                                                         #foCXhCo
   
   #`b2
   z <- read_data('out_lai_max_t.txt')                                            #f[^ǂ݂ƁA`
   png('out_lai_max_t.png', width=width_size, height=height_size)                 #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)                             #}{̂̕`
   draw_panel('Annual Maximum LAI of tree PFTs (m2/m2)', DivedNum, 7, PannelStep) #J[pldˏ
   dev.off()                                                                      #foCXhCo
   
   #`b3
   z  <- read_data('out_lai_max_g.txt')
   png('out_lai_max_g.png', width=width_size, height=height_size)                  #foCXhCoJ
   draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)                              #}{̂̕`
   draw_panel('Annual Maximum LAI of grass PFTs (m2/m2)', DivedNum, 7, PannelStep) #J[pldˏ
   dev.off()                                                                       #foCXhCo
  
#____________________ LAI_every_month ____________________ 
   DivedNum   <- 14                    #J[pl̕
   PannelStep <- 0.25                   #J[pl̑
   col <- set_color_terrain(DivedNum)  #_ƐF̐ݒ
   
   for (month in 1:12) {
      if (month <10) {z <- read_data(paste('out_lai_0', month, '.txt', sep=""))}
      else           {z <- read_data(paste('out_lai_' , month, '.txt', sep=""))}
      
      png( paste('out_lai_month',month,'.png'), width=width_size, height=height_size)
         draw_dist_LAI (DivedNum, PannelStep, col, x, y, z)
      dev.off()
   }
